@@ -11,4 +11,6 @@ __all__ = [
     'Downloader',
     'Tools',
     'Version',
+    'Nginx',
+    'Daemon',
 ]
\ No newline at end of file
